pub enum GnuKind {
LongName,
LongLink,
}Expand description
The supported GNU metadata extension kinds.
Variants
LongName
A typeflag L extension giving a long name for the next member.
LongLink
A typeflag K extension giving a long link name for the next member.