PaxError

Enum PaxError 

pub enum PaxError {
    InvalidRecords {
        reason: &'static str,
    },
    InvalidUtf8,
    InvalidKeyword {
        keyword: String,
    },
    InvalidInteger {
        keyword: &'static str,
        value: String,
    },
    InvalidTime {
        keyword: &'static str,
        value: String,
    },
    UnsupportedCharset {
        value: String,
    },
    ArithmeticOverflow {
        context: &'static str,
    },
}
An error encountered while parsing pax extended-header records.

Variants



InvalidRecords

A pax payload did not consist of valid extended-header records.

Fields

reason: &'static str

A concise description of the grammar violation.



InvalidUtf8

A pax text component that must be UTF-8 is not valid UTF-8.



InvalidKeyword

A pax record keyword is neither standard nor an accepted namespaced extension.

Fields

keyword: String

The rejected keyword.



InvalidInteger

A pax decimal integer field is malformed or exceeds this API’s integer range.

Fields

keyword: &'static str

The affected standard keyword.

value: String

The rejected textual value.



InvalidTime

A pax file-time value is malformed or exceeds this API’s integer range.

Fields

keyword: &'static str

The affected standard keyword.

value: String

The rejected textual value.



UnsupportedCharset

A pax hdrcharset record requests text encoding unsupported by this API.

Fields

value: String

The unsupported character-set identifier.



ArithmeticOverflow

A pax record length or offset overflowed.

Fields

context: &'static str

The computation that overflowed.