pub enum PaxValue<T> {
Value(T),
Deleted,
}Expand description
A parsed pax value, including an explicit deletion tombstone.
Deletion tombstones are needed because pax has special semantics for empty (i.e. deleted) pax records: they’re considered to delete “any header block field, previously entered extended header value, or global extended header value of the same name.”
This is a distinct state from “missing,” which allows for fallbacks to e.g. global pax headers or the equivalent ustar field.
Variants
Value(T)
This record sets or overrides the attribute.
Deleted
This record deletes the attribute from its applicable scope.