Module header

Module header 

Constants

CHECKSUM_RANGE
The byte range that a member’s checksum appears at in a tar block, whether pax/ustar or GNU.
DEVMAJOR_RANGE
The byte range that a member’s device-major value appears at in a pax/ustar block.
DEVMINOR_RANGE
The byte range that a member’s device-minor value appears at in a pax/ustar block.
GID_RANGE
The byte range that a member’s group ID appears at in a tar block, whether pax/ustar or GNU.
GNAME_RANGE
The byte range that a member’s group name appears at in a pax/ustar block.
GNU_IDENTITY
The magic and version bytes for a GNU tar block. Note that, despite not having the proper ustar identity, a GNU tar block uses a strict superset of the ustar typeflags.
IDENTITY_RANGE
The byte range that a member’s identity appears at in a tar block, whether pax/ustar or GNU.
LINK_NAME_RANGE
The byte range that a member’s link name (i.e. link target) appears at in a tar block, whether pax/ustar or GNU.
MODE_RANGE
The byte range that a member’s mode appears at in a tar block, whether pax/ustar or GNU.
MTIME_RANGE
The byte range that a member’s mtime appears at in a tar block, whether pax/ustar or GNU.
NAME_RANGE
The byte range that a member name appears at in a tar block, whether pax/ustar or GNU.
PREFIX_RANGE
The byte range that a member’s checksum appears at in a tar block.
SIZE_RANGE
The byte range that a member’s size appears at in a tar block, whether pax/ustar or GNU.
TYPEFLAG_OFFSET
The byte index that a member’s typeflag appears at in a tar block, whether pax/ustar or GNU.
UID_RANGE
The byte range that a member’s user ID appears at in a tar block, whether pax/ustar or GNU.
UNAME_RANGE
The byte range that a member’s user name appears at in a pax/ustar block.
USTAR_IDENTITY
The magic and version bytes for a ustar tar block. ustar blocks form the baseline for pax, since every pax block is a well-formed ustar block (and what makes it pax is whether it uses a pax typeflag).