MemberFrame

Struct MemberFrame 

pub struct MemberFrame<'a, R> {
    pub header: Header<'a>,
    pub extensions: MemberExtensions<'a>,
    pub payload: MemberPayload<'a, R>,
}
An ordinary archive member and its streaming payload cursor.

Fields

header: Header<'a>

The ordinary member header.

extensions: MemberExtensions<'a>

Extension metadata applying to this member.

payload: MemberPayload<'a, R>

A cursor over the member payload bytes.

Implementations

Source

impl<R> MemberFrame<'_, R>

pub fn effective_path(&self) -> Result<Cow<'_, [u8]>, FrameError>

Returns the effective member path after applying pax or GNU metadata.

An explicit pax deletion is an error because it also removes the ordinary-header fallback required to identify this member. Empty paths and paths containing embedded NUL bytes are also rejected.

Returns the effective member link target after applying pax or GNU metadata.

An explicit pax deletion is an error because it also removes the ordinary-header fallback required to identify a link target. Link targets containing embedded NUL bytes are also rejected.