pub struct PayloadBlock {
pub position: u64,
pub block: Block,
pub len: usize,
}Expand description
One meaningful payload block belonging to an ordinary archive member.
Fields
position: u64The absolute byte position of this payload block.
block: BlockThe lossless payload block bytes, including any final padding.
len: usizeThe number of meaningful bytes in this block.