pub struct DataFrame {
pub position: u64,
pub block: Block,
pub len: usize,
pub owner: DataOwner,
/* private fields */
}Expand description
A payload physical block.
This can be “real” data for e.g. a file member, or it can be the payload of a pax or GNU header.
Fields
position: u64The absolute byte position of this block in the source stream.
block: BlockThe lossless payload block bytes, including any final padding.
len: usizeThe number of meaningful payload bytes in this block.
owner: DataOwnerWhether this block carries metadata-extension or member data.
Implementations