pub struct GnuFrame {
pub position: u64,
pub block: Block,
pub kind: GnuKind,
pub payload_size: u64,
}Expand description
A GNU metadata extension header block.
Fields
position: u64The absolute byte position of this block in the source stream.
block: BlockThe lossless header block bytes.
kind: GnuKindThe GNU extension kind.
payload_size: u64The number of metadata payload bytes following the header.