pub struct PaxFrame {
pub position: u64,
pub block: Block,
pub kind: PaxKind,
pub payload_size: u64,
}Expand description
A pax extended header block.
Fields
position: u64The absolute byte position of this block in the source stream.
block: BlockThe lossless header block bytes.
kind: PaxKindWhether this header is local or global.
payload_size: u64The number of bytes occupied by the extended header records.